@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 import unittest
-from rawdisk.util.filetimes import dt_to_filetime, filetime_to_dt
+from rawdisk.util.filetimes import dt_to_filetime, filetime_to_dt, UTC, ZERO
 from datetime import datetime
 
 
@@ -15,5 +15,11 @@ class TestFiletimesModule(unittest.TestCase):
         value = 116444736000000000
         self.assertEquals(datetime(1970, 1, 1, 0, 0), filetime_to_dt(value))
 
+    def test_utc(self):
+        utc = UTC()
+
+        self.assertEquals(utc.tzname(None), "UTC")
+        self.assertEquals(utc.utcoffset(None), ZERO)
+
 if __name__ == "__main__":
     unittest.main()
